@@ -69,7 +69,7 @@ func (l *Local) RelationshipsFromDocker() Relationships {
 	}
 
 	opts := [](docker.Opt){docker.FromEnv}
-	if host := os.Getenv("DOCKER_HOST"); host != "" && !strings.HasPrefix(host, "unix://") {
+	if host := os.Getenv(docker.EnvOverrideHost); host != "" && !strings.HasPrefix(host, "unix://") {
 		// Setting a dialer on top of a unix socket breaks the connection
 		// as the client then tries to connect to http:///path/to/socket and
 		// thus tries to resolve the /path/to/socket host
@@ -182,13 +182,13 @@ func (l *Local) dockerServiceToRelationship(client *docker.Client, container typ
 		}
 	}
 
-	host := os.Getenv("DOCKER_HOST")
+	host := os.Getenv(docker.EnvOverrideHost)
 	if host == "" || strings.HasPrefix(host, "unix://") {
 		host = "127.0.0.1"
 	} else {
 		u, err := url.Parse(host)
 		if err != nil {
-			fmt.Fprintf(os.Stderr, "  ERROR: unable to parse DOCKER_HOST \"%s\", falling back to 127.0.0.1: %s\n", host, err)
+			fmt.Fprintf(os.Stderr, "  ERROR: unable to parse %s \"%s\", falling back to 127.0.0.1: %s\n", docker.EnvOverrideHost, host, err)
 			host = "127.0.0.1"
 		} else {
 			host = u.Hostname()
